@@ -3,79 +3,83 @@ if [ -x /usr/bin/update-desktop-database ]; then
   /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
 fi
 
-( cd usr/lib ; rm -rf libmarblewidget.so )
-( cd usr/lib ; ln -sf libmarblewidget.so.4 libmarblewidget.so )
-( cd usr/lib ; rm -rf libanalitzagui.so.4 )
-( cd usr/lib ; ln -sf libanalitzagui.so.4.4.0 libanalitzagui.so.4 )
-( cd usr/lib ; rm -rf libanalitza.so )
-( cd usr/lib ; ln -sf libanalitza.so.4 libanalitza.so )
-( cd usr/lib ; rm -rf libanalitza.so.4 )
-( cd usr/lib ; ln -sf libanalitza.so.4.4.0 libanalitza.so.4 )
-( cd usr/lib ; rm -rf libkeduvocdocument.so )
-( cd usr/lib ; ln -sf libkeduvocdocument.so.4 libkeduvocdocument.so )
-( cd usr/lib ; rm -rf libkeduvocdocument.so.4 )
-( cd usr/lib ; ln -sf libkeduvocdocument.so.4.4.0 libkeduvocdocument.so.4 )
-( cd usr/lib ; rm -rf libcantorlibs.so )
-( cd usr/lib ; ln -sf libcantorlibs.so.1 libcantorlibs.so )
-( cd usr/lib ; rm -rf libkdeeduui.so.4 )
-( cd usr/lib ; ln -sf libkdeeduui.so.4.4.0 libkdeeduui.so.4 )
-( cd usr/lib ; rm -rf libscience.so )
-( cd usr/lib ; ln -sf libscience.so.4 libscience.so )
-( cd usr/lib ; rm -rf libSatLib.so.4 )
-( cd usr/lib ; ln -sf libSatLib.so.4.4.0 libSatLib.so.4 )
-( cd usr/lib ; rm -rf libcantorlibs.so.1 )
-( cd usr/lib ; ln -sf libcantorlibs.so.0.0.1 libcantorlibs.so.1 )
-( cd usr/lib ; rm -rf libkiten.so )
-( cd usr/lib ; ln -sf libkiten.so.4 libkiten.so )
-( cd usr/lib ; rm -rf libkdeeduui.so )
-( cd usr/lib ; ln -sf libkdeeduui.so.4 libkdeeduui.so )
-( cd usr/lib ; rm -rf libanalitzagui.so )
-( cd usr/lib ; ln -sf libanalitzagui.so.4 libanalitzagui.so )
-( cd usr/lib ; rm -rf libmarblewidget.so.4 )
-( cd usr/lib ; ln -sf libmarblewidget.so.4.4.0 libmarblewidget.so.4 )
-( cd usr/lib ; rm -rf libkiten.so.4 )
-( cd usr/lib ; ln -sf libkiten.so.4.4.0 libkiten.so.4 )
-( cd usr/lib ; rm -rf libSatLib.so )
-( cd usr/lib ; ln -sf libSatLib.so.4 libSatLib.so )
-( cd usr/lib ; rm -rf libscience.so.4 )
-( cd usr/lib ; ln -sf libscience.so.4.4.0 libscience.so.4 )
-( cd usr/share/doc/HTML/en/ktouch ; rm -rf common )
-( cd usr/share/doc/HTML/en/ktouch ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kturtle ; rm -rf common )
-( cd usr/share/doc/HTML/en/kturtle ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/khangman ; rm -rf common )
 ( cd usr/share/doc/HTML/en/khangman ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kstars ; rm -rf common )
-( cd usr/share/doc/HTML/en/kstars ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/marble ; rm -rf common )
-( cd usr/share/doc/HTML/en/marble ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kig ; rm -rf common )
-( cd usr/share/doc/HTML/en/kig ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/parley ; rm -rf common )
-( cd usr/share/doc/HTML/en/parley ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/cantor ; rm -rf common )
-( cd usr/share/doc/HTML/en/cantor ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kbruch ; rm -rf common )
-( cd usr/share/doc/HTML/en/kbruch ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/kmplot ; rm -rf common )
 ( cd usr/share/doc/HTML/en/kmplot ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kwordquiz ; rm -rf common )
+( cd usr/share/doc/HTML/en/kwordquiz ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/ktouch ; rm -rf common )
+( cd usr/share/doc/HTML/en/ktouch ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/parley ; rm -rf common )
+( cd usr/share/doc/HTML/en/parley ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/rocs ; rm -rf common )
 ( cd usr/share/doc/HTML/en/rocs ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kbruch ; rm -rf common )
+( cd usr/share/doc/HTML/en/kbruch ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kstars ; rm -rf common )
+( cd usr/share/doc/HTML/en/kstars ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kanagram ; rm -rf common )
+( cd usr/share/doc/HTML/en/kanagram ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/blinken ; rm -rf common )
+( cd usr/share/doc/HTML/en/blinken ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/marble ; rm -rf common )
+( cd usr/share/doc/HTML/en/marble ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kalzium ; rm -rf common )
+( cd usr/share/doc/HTML/en/kalzium ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/klettres ; rm -rf common )
 ( cd usr/share/doc/HTML/en/klettres ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/kiten ; rm -rf common )
 ( cd usr/share/doc/HTML/en/kiten ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/blinken ; rm -rf common )
-( cd usr/share/doc/HTML/en/blinken ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kwordquiz ; rm -rf common )
-( cd usr/share/doc/HTML/en/kwordquiz ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kanagram ; rm -rf common )
-( cd usr/share/doc/HTML/en/kanagram ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kig ; rm -rf common )
+( cd usr/share/doc/HTML/en/kig ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/cantor ; rm -rf common )
+( cd usr/share/doc/HTML/en/cantor ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kturtle ; rm -rf common )
+( cd usr/share/doc/HTML/en/kturtle ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/kgeography ; rm -rf common )
 ( cd usr/share/doc/HTML/en/kgeography ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kalzium ; rm -rf common )
-( cd usr/share/doc/HTML/en/kalzium ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/step ; rm -rf common )
 ( cd usr/share/doc/HTML/en/step ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/kalgebra ; rm -rf common )
 ( cd usr/share/doc/HTML/en/kalgebra ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/lib ; rm -rf libcantorlibs.so.1 )
+( cd usr/lib ; ln -sf libcantorlibs.so.0.0.2 libcantorlibs.so.1 )
+( cd usr/lib ; rm -rf libmarblewidget.so.10 )
+( cd usr/lib ; ln -sf libmarblewidget.so.0.10.1 libmarblewidget.so.10 )
+( cd usr/lib ; rm -rf libkdeeduui.so.4 )
+( cd usr/lib ; ln -sf libkdeeduui.so.4.5.0 libkdeeduui.so.4 )
+( cd usr/lib ; rm -rf librocslib.so.4 )
+( cd usr/lib ; ln -sf librocslib.so.4.5.0 librocslib.so.4 )
+( cd usr/lib ; rm -rf libscience.so.4 )
+( cd usr/lib ; ln -sf libscience.so.4.5.0 libscience.so.4 )
+( cd usr/lib ; rm -rf libkiten.so )
+( cd usr/lib ; ln -sf libkiten.so.4 libkiten.so )
+( cd usr/lib ; rm -rf libkeduvocdocument.so )
+( cd usr/lib ; ln -sf libkeduvocdocument.so.4 libkeduvocdocument.so )
+( cd usr/lib ; rm -rf libscience.so )
+( cd usr/lib ; ln -sf libscience.so.4 libscience.so )
+( cd usr/lib ; rm -rf libkeduvocdocument.so.4 )
+( cd usr/lib ; ln -sf libkeduvocdocument.so.4.5.0 libkeduvocdocument.so.4 )
+( cd usr/lib ; rm -rf libcantorlibs.so )
+( cd usr/lib ; ln -sf libcantorlibs.so.1 libcantorlibs.so )
+( cd usr/lib ; rm -rf librocslib.so )
+( cd usr/lib ; ln -sf librocslib.so.4 librocslib.so )
+( cd usr/lib ; rm -rf libSatLib.so )
+( cd usr/lib ; ln -sf libSatLib.so.4 libSatLib.so )
+( cd usr/lib ; rm -rf libkdeeduui.so )
+( cd usr/lib ; ln -sf libkdeeduui.so.4 libkdeeduui.so )
+( cd usr/lib ; rm -rf libkiten.so.4 )
+( cd usr/lib ; ln -sf libkiten.so.4.5.0 libkiten.so.4 )
+( cd usr/lib ; rm -rf libanalitzagui.so.4 )
+( cd usr/lib ; ln -sf libanalitzagui.so.4.5.0 libanalitzagui.so.4 )
+( cd usr/lib ; rm -rf libSatLib.so.4 )
+( cd usr/lib ; ln -sf libSatLib.so.4.5.0 libSatLib.so.4 )
+( cd usr/lib ; rm -rf libmarblewidget.so )
+( cd usr/lib ; ln -sf libmarblewidget.so.10 libmarblewidget.so )
+( cd usr/lib ; rm -rf libanalitza.so.4 )
+( cd usr/lib ; ln -sf libanalitza.so.4.5.0 libanalitza.so.4 )
+( cd usr/lib ; rm -rf libanalitza.so )
+( cd usr/lib ; ln -sf libanalitza.so.4 libanalitza.so )
+( cd usr/lib ; rm -rf libanalitzagui.so )
+( cd usr/lib ; ln -sf libanalitzagui.so.4 libanalitzagui.so )
